#
# spec file for package miam-player
#
# Copyright (c) 2015 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           miam-player
Version:        0.9.0.20181216.1e95ab22
Release:        150500.3.pm.6
Summary:        A nice music player
License:        GPL-3.0+
Group:          Productivity/Multimedia/Sound/Players
Url:            https://github.com/MBach/Miam-Player
Source:         %{name}-%{version}.tar.xz
Source1:        %{name}.desktop
Patch0:         miam-player-0.9.0-qpainterpath.patch
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(libchromaprint)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  QtAV-devel
BuildRequires:  desktop-file-utils
# Miam Player doesn't work well with other sql backends
Requires:       libQt5Sql5-sqlite
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < %{version}-%{release}

%description
Miam Player is a FOSS music player based on Qt5.

Features:
 - Read .mp3, .m4a (MP4), .flac, .ogg, .oga (OGG Vorbis), .asf,
   .ape (Monkey Audio) and more.
 - Read and edit lots of tags using Taglib.
 - Customize everything: user interface, covers, shortcuts,
   buttons, themes.
 - Fast and reliable (audio player is based on QtAV).

A plugin system makes it possible to extend player possibilities.

%prep
%autosetup -p1

%build
%qmake5 \
%if "%{?_lib}" == "lib64"
    LIB_SUFFIX=64 \
%endif
    %{nil}
%make_jobs

%install
%qmake5_install
install -D -m 644 '%{SOURCE1}' %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -m 644 src/player/mp.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
%suse_update_desktop_file -i %{name}
find '%{buildroot}' -name '*.so' -type 'l' -print -delete

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun

%files
%license LICENSE
%{_bindir}/*
%{_libdir}/libmiam-*.so.*
%{_datadir}/appdata
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Tue Jul 21 2020 Fridrich Strba <fridrich.strba@bluewin.ch>
- Added patch:
  * miam-player-0.9.0-qpainterpath.patch
    + Fix aggregate QPainterPath has incomplete type errors
* Wed Feb  5 2020 olaf@aepfle.de
- Update to 0.9.0.20181216.1e95ab22
* Sat Feb 27 2016 antoine.belvire@laposte.net
- Update to 0.8.0:
  * New way to play your music: the Unique Library Mode (or Single
    Library Mode)
  * VLC and its wrapper VLC-Qt are replaced by QtAV
  * Custom colors are greatly improved (still, there's a minor bug
    in options dialog)
  * Default shortcuts to quickly move the vertical slider in the
    library: just press letters from A to Z
  * New material design theme for media buttons
  * Big improvements on performance and memory consumption (lazy
    loading on every dialog, and multi-threading for scanning
    music: no more blocking UI)
  * Add support for Multimedia keys
  * Cover-fetcher plugin: support Amazon provider
  * Random mode for playlists: not a real random anymore: tracks
    cannot be played twice if the whole playlist hasn't been
    played first.
  * New: Chinese translation, thanks to @wang-bin
  * Updated: Russian translation, thanks to @Ilya87
- Adapt miam-player-patch.sh to new archive layout
- Remove miam-player-libsuffix.patch (LIB_SUFFIX is now supported
  by upstream)
- Add miam-player-0.8.0-fix-include.patch: fix wrong include
- Add patches to included qxt:
  * Add miam-player-8.0-fix-qxt-link.patch: add -lX11 to fix build
  * Add libqxt-media-keys.patch: without it, media keys don't work
    and keyboard is "blocked" on GNOME; patch is picked from
    repo's libqxt1 (which we can't use directly because it is built
    only for qt4)
- Do not depend anymore on ImageMagick for icons: just copy the
  upstream icon - that is now a png - into /usr/share/pixmaps
* Thu Oct  1 2015 antoine.belvire@laposte.net
- Update to 0.7.3:
  * Enhancements:
    + Support opening a file with a command-line argument (issue #10)
    + 10-band equalizer (#43)
    + Improve random playback mode (#40)
    + Give exitAction the QuitRole role (#49)
    + Replace star picture in settings with a computer generated
    star: a better support for high DPI screens
    + Much better Dark Theme in custom colors mode
    + Update Czech translation (thanks to Pavel)
    + Rename playlists in Playlist Manager or directly when
    displaying Context Menu on playlist tab
    + Add keyboard shortcuts in the FileSystem Manager
  * Bug fixes:
    + Ignore articles like "the" when sorting Artists (#28)
    + Playlist are doubled (#33)
    + Automatically hide Extended Search Widget when losing focus
- Remove miam-player-0.7.2-add-missing-include.patch (upstreamed)
* Thu Oct  1 2015 antoine.belvire@laposte.net
- Fix build with Qt 5.5:
  * add miam-player-0.7.2-add-missing-include.patch
* Mon May  4 2015 antoine.belvire@laposte.net
- Update to 0.7.2:
  * improve display of AddressBar in File Explorer (issue #13)
  * extend the stop button (#15)
  * allow custom genres when editing tags (#17)
  * keep library up-to-date (#18)
  * add opus encoder support (#34)
  * pause/resume track leads to playback from the beginning (#39)
  * search area in Playlist is too small on Linux / KDE (#41)
  * reload cover with higher resolution when increasing size in Options (#44)
* Sat Apr 25 2015 antoine.belvire@laposte.net
- Fix build for Factory (option -C is ignored with %%qmake5_install
  for this target)
* Thu Apr 23 2015 antoine.belvire@laposte.net
- Modify requirements in spec:
  * requires explicitely libQt5Sql5-sqlite
  * requires vlc-noX
  * recommends vlc-codecs
* Thu Apr 23 2015 joerg.lorenzen@ki.tng.de
- Build with optflags and added vlc-codecs as required package.
* Wed Apr 22 2015 sor.alexei@meowr.ru
- Rename miam-player-0.7.1-libsuff.patch to
  miam-player-libsuffix.patch and change variable name to LIBSUFFIX.
- Remove useless binary stuff from source package to reduce size
  (thanks to joerg.lorenzen@ki.tng.de).
- Use miam-player-patch-source.sh to automate size reduce.
- Minor spec cleanup.
* Sun Apr 19 2015 antoine.belvire@laposte.net
- Fix desktop file (missing Name tag)
* Fri Apr 17 2015 antoine.belvire@laposte.net
- Add desktop file
- Other modifications in spec file:
  * create devel package
  * add ldconfig calls in %%post and %%postun
* Thu Apr 16 2015 antoine.belvire@laposte.net
- New package for Miam Player
- Version 0.7.1:
  * redesign the seekbar
  * allow one to move tabs
  * improve Quick Start widget (shows the default music location if exists)
  * sync remote sources when scanning the whole library
  * improve the playlist manager
  * restrict drop areas other than playlists when moving tracks
  * VLC-Qt updated to 0.10.0
  * Russian translation
  * various fixes
